@@ -3,6 +3,7 @@ Views that inherit from Django's class-based generic views and add methods
 for building flat files.
 """
 import os
+import shutil
 import logging
 from django.conf import settings
 from django.test.client import RequestFactory
@@ -39,7 +40,7 @@ class BuildableTemplateView(TemplateView):
         dirname = os.path.dirname(self.build_path)
         if dirname:
             dirname = os.path.join(settings.BUILD_DIR, dirname)
-            os.path.exists(dirname) or os.mkdir(dirname)
+            os.path.exists(dirname) or os.makedirs(dirname)
         # Write out the data
         outfile = open(path, 'w')
         outfile.write(html)
@@ -79,7 +80,7 @@ class BuildableListView(ListView):
         dirname = os.path.dirname(self.build_path)
         if dirname:
             dirname = os.path.join(settings.BUILD_DIR, dirname)
-            os.path.exists(dirname) or os.mkdir(dirname)
+            os.path.exists(dirname) or os.makedirs(dirname)
         # Render the list page as HTML
         html = self.get(self.request).render().content
         # Write it out to the appointed flat file
@@ -154,6 +155,16 @@ class BuildableDetailView(DetailView):
         [self.build_object(o) for o in self.queryset.all()]
 
 
+    def unbuild_object(self, obj):
+        """
+        Deletes the directory at self.get_build_path.
+        """
+        logger.debug("Unbuilding %s" % obj)
+        path = os.path.split(self.get_build_path(obj))[0]
+        if os.path.exists(path): 
+            shutil.rmtree(path)
+
+
 class Buildable404View(BuildableTemplateView):
     """
     The default Django 404 page, but built out.
